Estimators
===========================

.. autoclass:: kooplearn.estimators.LowRankRegressor
   :members:
   :undoc-members:

.. autoclass:: kooplearn.estimators.ReducedRank
   :members:
   :undoc-members:

   .. automethod:: __init__

.. autoclass:: kooplearn.estimators.PrincipalComponent
   :members:
   :undoc-members:

   .. automethod:: __init__